from openfisca_uk_data import UKMODOutput, FRSEnhanced
from openfisca_uk.initial_setup import set_default

FRSEnhanced.download(2018)
FRSEnhanced.download(2019)
UKMODOutput.download(2018)
set_default(FRSEnhanced)



from openfisca_uk.tools.simulation import Microsimulation
import pandas as pd
from openfisca_uk import BASELINE_VARIABLES


def formalise_column_names(df: pd.DataFrame) -> pd.DataFrame:
    """Exchanges column names for their labels if possible

    Args:
        df (pd.DataFrame): The dataframe containing variable names in columns.

    Returns:
        pd.DataFrame: The dataframe with columns renamed.
    """
    column_mapping = {}
    for i in range(len(df.columns)):
        name = df.columns[i]
        if "baseline_" in name or "reform_" in name:
            variable_name = (
                name.replace("baseline_", "")
                .replace("reform_", "")
                .replace("_deriv", "")
            )
            tag = {True: " (Baseline)", False: " (Reform)"}[
                "baseline_" in name
            ]
            if variable_name in BASELINE_VARIABLES:
                column_mapping[
                    name
                ] = f"{BASELINE_VARIABLES[variable_name].label}{tag}"
            else:
                column_mapping[name] = f"{variable_name}{tag}"
        elif name == "reform":
            column_mapping[name] = "Reform"
        elif name in BASELINE_VARIABLES:
            column_mapping[name] = BASELINE_VARIABLES[name].label
    df.columns = df.columns.map(column_mapping)
    return df, column_mapping


def net_cost(
    baseline_sim: Microsimulation,
    reform_sim: Microsimulation,
    invert: bool = False,
    variable: str = "net_income",
) -> float:
    if invert:
        multiplier = -1
    else:
        multiplier = 1
    return multiplier * (
        reform_sim.calc(variable).sum() - baseline_sim.calc(variable).sum()
    )


GREY, DARK_BLUE = ("#BDBDBD", "#0F4AA1")
COLORS = (GREY, DARK_BLUE)



from openfisca_uk.model_api import *


class LHA_eligible(Variable):
    value_type = float
    entity = BenUnit
    label = "Eligibility for Local Housing Allowance"
    documentation = (
        "Whether benefit unit is eligible for Local Housing Allowance"
    )
    definition_period = YEAR

    def formula(benunit, period, parameters):
        renting = benunit("benunit_is_renting", period)
        anyone_in_social_housing = benunit.any(
            benunit.members("in_social_housing", period)
        )
        return renting & ~anyone_in_social_housing


class LHA_allowed_bedrooms(Variable):
    value_type = float
    entity = BenUnit
    label = "The number of bedrooms covered by LHA for the benefit unit"
    definition_period = YEAR
    reference = "https://www.legislation.gov.uk/uksi/2013/376/schedule/4/paragraph/10/2021-04-06"

    def formula(benunit, period, parameters):
        """
        LHA allows for one room for:
        a) The benefit unit adult(s)
        b) Each person over 16 outside the benefit unit
            but within the household
        Children must share rooms in pairs unless they are
        opposite-sex and one is over 10. The number of bedrooms
        allowed under LHA rules is the minimum number of bedrooms
        required to allocate people satisfying these rules.
        """
        person = benunit.members
        age = person("age", period)
        male = person("is_male", period)
        under_16 = age < 16
        under_10 = age < 10
        child_over_10 = ~under_10 & under_16
        # One room each for over-16s outside the benefit unit
        non_dependants = benunit.max(
            person.household.sum(~under_16)
        ) - benunit.sum(~under_16)
        boys_under_10 = benunit.sum(under_10 & male)
        boys_over_10 = benunit.sum(child_over_10 & male)
        girls_under_10 = benunit.sum(under_10 & ~male)
        girls_over_10 = benunit.sum(child_over_10 & ~male)
        # First, have over-10s share where possible
        over_10_rooms = (boys_over_10 + 1) // 2 + (girls_over_10 + 1) // 2
        # There may children over 10 still not sharing
        space_for_boy_under_10 = boys_over_10 % 2
        space_for_girl_under_10 = girls_over_10 % 2
        # Have those spaces filled where possible by children under 10
        left_over_boys_under_10 = max_(
            boys_under_10 - space_for_boy_under_10, 0
        )
        left_over_girls_under_10 = max_(
            girls_under_10 - space_for_girl_under_10, 0
        )
        # The remaining children must share in pairs
        under_10_rooms = (
            left_over_boys_under_10 + left_over_girls_under_10 + 1
        ) // 2
        return 1 + non_dependants + over_10_rooms + under_10_rooms


class LHA_cap(Variable):
    value_type = float
    entity = BenUnit
    label = "Applicable amount for LHA"
    documentation = "Applicable amount for Local Housing Allowance"
    definition_period = YEAR
    unit = "currency-GBP"

    def formula(benunit, period, parameters):
        rent = benunit("benunit_rent", period)
        cap = benunit("BRMA_LHA_rate", period)
        return min_(rent, cap)


class LHACategory(Enum):
    A = "Shared"
    B = "1 Bed"
    C = "2 Bed"
    D = "3 Bed"
    E = "4+ Bed"


class LHA_category(Variable):
    value_type = Enum
    entity = BenUnit
    label = "LHA category for the benefit unit, taking into account LHA rules on the number of LHA-covered bedrooms"
    definition_period = YEAR
    possible_values = LHACategory
    default_value = LHACategory.C

    def formula(benunit, period, parameters):
        num_rooms = benunit("LHA_allowed_bedrooms", period.this_year)
        person = benunit.members
        household = person.household
        is_shared = benunit.any(
            household("is_shared_accommodation", period.this_year)
        )
        num_adults_in_hh = benunit.max(
            household.sum(person("is_adult", period))
        )
        eldest_adult_age_in_hh = benunit.max(
            household.max(person("age", period))
        )
        # Households with only one adult, if under 35, can only claim shared.
        can_only_claim_shared = (num_adults_in_hh == 1) & (
            eldest_adult_age_in_hh < 35
        )
        return select(
            [
                is_shared | can_only_claim_shared,
                num_rooms == 1,
                num_rooms == 2,
                num_rooms == 3,
                num_rooms > 3,
            ],
            [
                LHACategory.A,
                LHACategory.B,
                LHACategory.C,
                LHACategory.D,
                LHACategory.E,
            ],
        )


class BRMA_LHA_rate(Variable):
    value_type = float
    entity = BenUnit
    label = "LHA rate"
    documentation = "Local Housing Allowance rate"
    definition_period = YEAR
    unit = "currency-GBP"

    def formula(benunit, period, parameters):
        BRMA = benunit.value_from_first_person(
            benunit.members.household("BRMA", period).decode_to_str()
        )
        category = benunit("LHA_category", period)
        rate = parameters(period).benefit.LHA.rates[BRMA][category]
        return rate * WEEKS_IN_YEAR



from openfisca_uk.model_api import *


class student_loans(Variable):
    value_type = float
    entity = Person
    label = "Student loans"
    definition_period = YEAR
    unit = "currency-GBP"


class student_payments(Variable):
    value_type = float
    entity = Person
    label = "Student payments"
    definition_period = YEAR
    unit = "currency-GBP"



from openfisca_uk.model_api import *


class pension_credit_reported(Variable):
    value_type = float
    entity = Person
    label = "Reported amount of Pension Credit"
    definition_period = YEAR
    unit = "currency-GBP"


class would_claim_PC(Variable):
    value_type = bool
    entity = BenUnit
    label = "Would claim Pension Credit"
    documentation = (
        "Whether this family would claim Pension Credit if eligible"
    )
    definition_period = YEAR

    def formula(benunit, period, parameters):
        takeup_rate = parameters(period).benefit.pension_credit.takeup
        takes_up = random(benunit) < takeup_rate
        return takes_up | benunit("claims_all_entitled_benefits", period)


class claims_PC(Variable):
    value_type = bool
    entity = BenUnit
    label = "Whether this family is imputed to claim Pension Credit"
    definition_period = YEAR

    def formula(benunit, period, parameters):
        return benunit("would_claim_PC", period)


class pension_credit_eligible(Variable):
    value_type = bool
    entity = BenUnit
    label = "Eligible for Pension Credit"
    definition_period = YEAR

    def formula(benunit, period):
        person_is_SP_age = benunit.members("is_SP_age", period)
        all_SP_age = benunit.all(person_is_SP_age)
        any_SP_age = benunit.any(person_is_SP_age)
        claiming_HB = benunit("housing_benefit", period) > 0
        return all_SP_age | (any_SP_age & claiming_HB)


class pension_credit_MG(Variable):
    value_type = float
    entity = BenUnit
    label = "Pension Credit (Minimum Guarantee) amount per week"
    definition_period = YEAR
    unit = "currency-GBP"

    def formula(benunit, period, parameters):
        mg = parameters(period).benefit.pension_credit.minimum_guarantee
        relation_type = benunit("relation_type", period)
        personal_allowance = mg[relation_type] * WEEKS_IN_YEAR
        premiums = add(
            benunit, period, ["severe_disability_premium", "carer_premium"]
        )
        applicable_amount = personal_allowance + premiums
        return (
            applicable_amount
            * benunit("pension_credit_eligible", period)
            * benunit("claims_PC", period)
        )


class guarantee_credit_applicable_income(Variable):
    value_type = float
    entity = BenUnit
    label = "Applicable income for Pension Credit"
    definition_period = YEAR
    unit = "currency-GBP"

    def formula(benunit, period, parameters):
        INCOME_COMPONENTS = [
            "personal_benefits",
            "pension_income",
            "maintenance_income",
            "employment_income",
            "self_employment_income",
            "property_income",
            "savings_interest_income",
            "dividend_income",
        ]
        income = aggr(benunit, period, INCOME_COMPONENTS)
        tax = aggr(benunit, period, ["tax"])
        BENEFIT_COMPONENTS = [
            "child_benefit",
            "child_tax_credit",
            "working_tax_credit",
            "housing_benefit",
        ]
        benefits = add(benunit, period, BENEFIT_COMPONENTS)
        return max_(income + benefits - tax, 0)


class pension_credit_GC(Variable):
    value_type = float
    entity = BenUnit
    label = "Pension Credit (Guarantee Credit) amount"
    definition_period = YEAR
    unit = "currency-GBP"

    def formula(benunit, period, parameters):
        income = benunit("guarantee_credit_applicable_income", period)
        amount = max_(0, benunit("pension_credit_MG", period) - income)
        return (
            benunit("pension_credit_eligible", period)
            * benunit("claims_PC", period)
            * amount
        )


class savings_credit_applicable_income(Variable):
    value_type = float
    entity = BenUnit
    label = "Applicable income for Savings Credit"
    definition_period = YEAR
    unit = "currency-GBP"
    reference = "https://www.gov.uk/government/publications/pension-credit-technical-guidance/a-detailed-guide-to-pension-credit-for-advisers-and-others#working-out-income-for-savings-credit"

    def formula(benunit, period, parameters):
        GC_income = benunit("guarantee_credit_applicable_income", period)
        EXEMPTED_PERSONAL_BENEFITS = [
            "incapacity_benefit",
            "JSA_contrib",
            "ESA_contrib",
            "SDA",
            "maintenance_income",
        ]
        exempted_personal_benefits = aggr(
            benunit, period, EXEMPTED_PERSONAL_BENEFITS
        )
        EXEMPTED_FAMILY_BENEFITS = ["working_tax_credit"]
        exempted_family_benefits = add(
            benunit,
            period,
            EXEMPTED_FAMILY_BENEFITS,
        )
        return max_(
            GC_income - exempted_personal_benefits - exempted_family_benefits,
            0,
        )


class pension_credit_SC(Variable):
    value_type = float
    entity = BenUnit
    label = "Pension Credit (Savings Credit) amount per week"
    definition_period = YEAR
    unit = "currency-GBP"
    reference = "https://www.gov.uk/government/publications/pension-credit-technical-guidance/a-detailed-guide-to-pension-credit-for-advisers-and-others#legislation-60-return"

    def formula(benunit, period, parameters):
        SC = parameters(period).benefit.pension_credit.savings_credit
        income = benunit("savings_credit_applicable_income", period)
        appropriate_amount = benunit("pension_credit_MG", period)
        threshold = (
            SC.income_threshold[benunit("relation_type", period)]
            * WEEKS_IN_YEAR
        )
        maximum_amount = (1 - SC.withdrawal_rate) * max_(
            appropriate_amount - threshold, 0
        )
        amount_A = min_(
            (1 - SC.withdrawal_rate) * max_(income - threshold, 0),
            maximum_amount,
        )
        amount_B = max_(income - appropriate_amount, 0) * SC.withdrawal_rate
        amount = max_(amount_A - amount_B, 0)
        return (
            amount
            * benunit("pension_credit_eligible", period)
            * benunit("claims_PC", period)
        )


class pension_credit(Variable):
    value_type = float
    entity = BenUnit
    label = "Pension Credit"
    definition_period = YEAR
    unit = "currency-GBP"

    def formula(benunit, period, parameters):
        COMPONENTS = ["pension_credit_GC", "pension_credit_SC"]
        return add(benunit, period, COMPONENTS)



from openfisca_uk.model_api import *


class winter_fuel_allowance_reported(Variable):
    value_type = float
    entity = Person
    label = "Winter fuel allowance"
    definition_period = YEAR
    unit = "currency-GBP"



from openfisca_uk.model_api import *


class corporate_wealth(Variable):
    label = "Corporate wealth"
    documentation = "Total owned wealth in corporations"
    entity = Household
    definition_period = YEAR
    value_type = float
    unit = "currency-GBP"


class shareholding(Variable):
    label = "Share in the corporate sector"
    documentation = "Exposure to taxes on corporations"
    entity = Household
    definition_period = YEAR
    value_type = float
    unit = "currency-GBP"

    def formula(household, period, parameters):
        nbs = parameters(period).wealth.national_balance_sheet
        wealth = household("corporate_wealth", period)
        total_wealth = (wealth * household("household_weight", period)).sum()
        total_wealth = where(
            total_wealth > 0, total_wealth, nbs.household.financial_net_worth
        )
        return wealth / total_wealth


class corporate_tax_incidence(Variable):
    label = "Corporate tax incidence"
    documentation = (
        "Reduction in value of corporate wealth due to taxes on corporations"
    )
    entity = Household
    definition_period = YEAR
    value_type = float
    unit = "currency-GBP"

    def formula(household, period):
        TAXES = [
            "corporate_sdlt_change_incidence",
            "business_rates_change_incidence",
        ]
        return add(household, period, TAXES)



from openfisca_uk.model_api import *


class JSA_contrib(Variable):
    value_type = float
    entity = Person
    label = "JSA (contribution-based)"
    definition_period = YEAR
    unit = "currency-GBP"

    def formula(person, period, parameters):
        return person("JSA_contrib_reported", period)


class JSA_contrib_reported(Variable):
    value_type = float
    entity = Person
    label = "Job Seeker's Allowance (contribution-based) (reported)"
    definition_period = YEAR
    unit = "currency-GBP"



from openfisca_uk.model_api import *


class owned_land(Variable):
    entity = Household
    label = "Owned land"
    documentation = "Total value of all land-only plots owned by the household"
    unit = "currency-GBP"
    definition_period = YEAR
    value_type = float


class land_value(Variable):
    label = "Land value"
    documentation = (
        "Estimated total land value (directly and indirectly owned)"
    )
    entity = Household
    definition_period = YEAR
    value_type = float
    unit = "currency-GBP"

    def formula(household, period):
        VARIABLES = [
            "household_land_value",
            "corporate_land_value",
        ]
        return add(household, period, VARIABLES)


class household_land_value(Variable):
    entity = Household
    label = "Land value"
    documentation = (
        "Estimated total land value directly owned by the household"
    )
    unit = "currency-GBP"
    definition_period = YEAR
    value_type = float

    def formula(household, period, parameters):
        property_wealth = household("property_wealth", period)
        total_property_wealth = (
            property_wealth * household("household_weight", period)
        ).sum()
        land = parameters(period).wealth.land
        property_wealth_intensity = (
            land.value.aggregate_household_land_value / total_property_wealth
        )
        property_wealth_intensity = where(
            total_property_wealth > 0,
            property_wealth_intensity,
            land.intensity.property_wealth,
        )
        owned_land = household("owned_land", period)
        return property_wealth * property_wealth_intensity + owned_land


class corporate_land_value(Variable):
    entity = Household
    label = "Land value"
    documentation = "Estimated total land value indirectly owned by the household from corporate holdings"
    unit = "currency-GBP"
    definition_period = YEAR
    value_type = float

    def formula(household, period, parameters):
        corporate_wealth = household("corporate_wealth", period)
        total_corporate_wealth = (
            corporate_wealth * household("household_weight", period)
        ).sum()
        land = parameters(period).wealth.land
        corporate_wealth_intensity = (
            land.value.aggregate_corporate_land_value / total_corporate_wealth
        )
        corporate_wealth_intensity = where(
            total_corporate_wealth > 0,
            corporate_wealth_intensity,
            land.intensity.corporate_wealth,
        )
        return corporate_wealth * corporate_wealth_intensity



from openfisca_uk.model_api import *


class property_sale_rate(Variable):
    label = "Residential property sale rate"
    documentation = "The percentage of residential property value owned by households sold in the year"
    entity = State
    definition_period = YEAR
    value_type = float
    unit = "/1"

    def formula(household, period, parameters):
        stamp_duty = parameters(period).hmrc.stamp_duty.statistics
        nbs = parameters(period).wealth.national_balance_sheet
        total_sale_value = (
            stamp_duty.residential.household.transaction_values
            + stamp_duty.non_residential.household.transaction_values
        )
        total_value = (
            nbs.household.dwellings
            + nbs.household.other_structures
            + nbs.household.land
        )
        return total_sale_value / total_value


class property_purchased(Variable):
    label = "All property bought this year"
    documentation = "Whether all property wealth was bought this year"
    entity = Household
    definition_period = YEAR
    value_type = bool
    unit = "currency-GBP"
    default_value = True


class main_residential_property_purchased(Variable):
    label = "Residential property bought (main)"
    documentation = "The price paid for the purchase of a residential property in the year, for use as a main residence. Only include the value of a single purchase."
    entity = Household
    definition_period = YEAR
    value_type = float
    unit = "currency-GBP"

    def formula(household, period):
        property_purchased = household("property_purchased", period)
        main_residence_value = household("main_residence_value", period)
        return main_residence_value * property_purchased


class additional_residential_property_purchased(Variable):
    label = "Residential property bought (additional)"
    documentation = "The price paid for the purchase of a residential property in the year, for use as a second home or another non-main-residence purpose. Only include the value of a single purchase."
    entity = Household
    definition_period = YEAR
    value_type = float
    unit = "currency-GBP"

    def formula(household, period):
        property_purchased = household("property_purchased", period)
        other_residential_property_value = household(
            "other_residential_property_value", period
        )
        return other_residential_property_value * property_purchased


class main_residential_property_purchased_is_first_home(Variable):
    label = "Residential property bought is first home"
    documentation = "Whether the residential property bought this year as a main residence was as a first-time buyer."
    entity = Household
    definition_period = YEAR
    value_type = bool
    unit = "currency-GBP"

    def formula(household, period, parameters):
        residential_sd = parameters(
            period
        ).hmrc.stamp_duty.statistics.residential.household
        age = household.sum(
            household.members("is_household_head", period)
            * household.members("age", period)
        )
        percentage_claiming_ftbr = (
            residential_sd.first_time_buyers_relief.calc(age)
            / residential_sd.transactions_by_age.calc(age)
        )
        return random(household) < percentage_claiming_ftbr


class cumulative_residential_rent(Variable):
    label = "Cumulative residential rent"
    documentation = "Total rent paid over the lifetime of the residential property a tenancy is held for."
    entity = Household
    definition_period = YEAR
    value_type = float
    unit = "currency-GBP"


class non_residential_property_purchased(Variable):
    label = "Non-residential property bought"
    documentation = "The price paid for the purchase of a non-residential property in the year. Only include the value of a single purchase."
    entity = Household
    definition_period = YEAR
    value_type = float
    unit = "currency-GBP"

    def formula(household, period):
        property_purchased = household("property_purchased", period)
        non_residential_property_value = household(
            "non_residential_property_value", period
        )
        return property_purchased * non_residential_property_value


class cumulative_non_residential_rent(Variable):
    label = "Cumulative non-residential rent"
    documentation = "Total rent paid over the lifetime of the non-residential property a tenancy is held for."
    entity = Household
    definition_period = YEAR
    value_type = float
    unit = "currency-GBP"


class rent(Variable):
    label = "Rent"
    documentation = (
        "The total amount of rent paid by the household in the year."
    )
    entity = Household
    definition_period = YEAR
    value_type = float
    unit = "currency-GBP"


class non_residential_rent(Variable):
    label = "Non-residential rent"
    documentation = "The total amount of rent paid by the household in the year for non-residential property."
    entity = Household
    definition_period = YEAR
    value_type = float
    unit = "currency-GBP"



from openfisca_uk.model_api import *


class state_pension_age(Variable):
    value_type = float
    entity = Person
    label = "State Pension age for this person"
    definition_period = YEAR
    unit = "year"

    def formula(person, period, parameters):
        SP = parameters(period).benefit.state_pension
        return where(person("is_male", period), SP.male_age, SP.female_age)


class is_SP_age(Variable):
    value_type = bool
    entity = Person
    label = "Whether the person is State Pension Age"
    definition_period = YEAR

    def formula(person, period, parameters):
        age = person("age", period)
        threshold = person("state_pension_age", period)
        return age >= threshold


class triple_lock_uprating(Variable):
    value_type = float
    entity = Person
    label = "Triple lock relative increase"
    documentation = (
        "A government commitment, rather than a legislative requirement"
    )
    definition_period = YEAR

    def formula(person, period, parameters):
        uprating = parameters(period).uprating
        uprating_ly = parameters(period.last_year).uprating
        cpi_growth = uprating.CPI / uprating_ly.CPI
        earnings_growth = uprating.earnings / uprating_ly.earnings
        return max(
            parameters(period).benefit.state_pension.triple_lock_minimum,
            cpi_growth,
            earnings_growth,
        )


class state_pension(Variable):
    value_type = float
    entity = Person
    label = "Income from the State Pension"
    definition_period = YEAR
    unit = "currency-GBP"
    documentation = "Gross State Pension payments"
    unit = "currency-GBP"

    def formula(person, period, parameters):
        return person("state_pension_reported", period)


class state_pension_reported(Variable):
    value_type = float
    entity = Person
    label = "Reported income from the State Pension"
    definition_period = YEAR
    unit = "currency-GBP"

    def formula_2015(person, period, parameters):
        sp_ly = person("state_pension_reported", period.last_year)
        return sp_ly * person("triple_lock_uprating", period)



from openfisca_uk.model_api import *


class food_and_non_alcoholic_beverages_consumption(Variable):
    entity = Household
    label = "Food and alcoholic beverages"
    documentation = "Total yearly expenditure on food and alcoholic beverages"
    unit = "currency-GBP"
    definition_period = YEAR
    value_type = float


class alcohol_and_tobacco_consumption(Variable):
    entity = Household
    label = "Alcohol and tobacco"
    documentation = "Total yearly expenditure on alcohol and tobacco"
    unit = "currency-GBP"
    definition_period = YEAR
    value_type = float


class clothing_and_footwear_consumption(Variable):
    entity = Household
    label = "Clothing and footwear"
    documentation = "Total yearly expenditure on clothing and footwear"
    unit = "currency-GBP"
    definition_period = YEAR
    value_type = float


class housing_water_and_electricity_consumption(Variable):
    entity = Household
    label = "Housing, water and electricity"
    documentation = (
        "Total yearly expenditure on housing, water and electricity"
    )
    unit = "currency-GBP"
    definition_period = YEAR
    value_type = float


class household_furnishings_consumption(Variable):
    entity = Household
    label = "Household furnishings"
    documentation = "Total yearly expenditure on household furnishings"
    unit = "currency-GBP"
    definition_period = YEAR
    value_type = float


class health_consumption(Variable):
    entity = Household
    label = "Health"
    documentation = "Total yearly expenditure on health"
    unit = "currency-GBP"
    definition_period = YEAR
    value_type = float


class transport_consumption(Variable):
    entity = Household
    label = "Transport"
    documentation = "Total yearly expenditure on transport"
    unit = "currency-GBP"
    definition_period = YEAR
    value_type = float


class communication_consumption(Variable):
    entity = Household
    label = "Communication"
    documentation = "Total yearly expenditure on communication"
    unit = "currency-GBP"
    definition_period = YEAR
    value_type = float


class recreation_consumption(Variable):
    entity = Household
    label = "Recreation"
    documentation = "Total yearly expenditure on recreation"
    unit = "currency-GBP"
    definition_period = YEAR
    value_type = float


class education_consumption(Variable):
    entity = Household
    label = "Education"
    documentation = "Total yearly expenditure on education"
    unit = "currency-GBP"
    definition_period = YEAR
    value_type = float


class restaurants_and_hotels_consumption(Variable):
    entity = Household
    label = "Restaurants and hotels"
    documentation = "Total yearly expenditure on restaurants and hotels"
    unit = "currency-GBP"
    definition_period = YEAR
    value_type = float


class miscellaneous_consumption(Variable):
    entity = Household
    label = "Miscellaneous"
    documentation = "Total yearly expenditure on miscellaneous goods"
    unit = "currency-GBP"
    definition_period = YEAR
    value_type = float
